@@ -1,17 +1,17 @@
-import sys
 import os
+import sys
 
 import dotenv
 import hydra
-from omegaconf import DictConfig
 from ipdb import set_trace
+from omegaconf import DictConfig
 
 # load environment variables from `.env` file if it exists
 # recursively searches for `.env` in all folders starting from work dir
 dotenv.load_dotenv(override=True)
 
 
-@hydra.main(config_path="configs/", config_name="config.yaml")
+@hydra.main(version_base="1.2", config_path="configs/", config_name="config.yaml")
 def main(config: DictConfig):
 
     # Imports should be nested inside @hydra.main to optimize tab completion
